# automatix
Automation wrapper for bash and python commands

**Automatix is still in development and not ready for productive use!**

Especially documentation is missing and will be added in near future.

## Warning:

Automatix evaluates YAML files and executes defined commands as shell or python commands.
There is no check for harmful commands. Be aware that this can cause critical damage to your system.

Please use the interactive mode and doublecheck commands before executing.
Usage of automatix is at your own risk (see also [terms of license](./LICENSE)).


## Installation

Automatix requires Python &ge; 3.6.

```
pip install automatix
```